;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "transient" "20260511.1436"
  "Transient commands."
  '((emacs    "28.1")
    (compat   "31.0")
    (cond-let "1.1")
    (seq      "2.24"))
  :url "https://github.com/magit/transient"
  :commit "7871d8f3e3e0eb9128dcd2a0e8b707b421c5e14c"
  :revdesc "7871d8f3e3e0"
  :keywords '("extensions")
  :authors '(("Jonas Bernoulli" . "emacs.transient@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.transient@jonas.bernoulli.dev")))
